#
# spec file for package sblim-wbemcli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sblim-wbemcli
BuildRequires:  binutils-devel
BuildRequires:  curl-devel
BuildRequires:  gcc-c++
Version:        1.6.3
Release:        3.4
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
URL:            http://sblim.wiki.sourceforge.net/
Source:         http://prdownloads.sourceforge.net/sblim/%{name}-%{version}.tar.bz2
Patch0:         sblim-wbemcli-allow-tls.patch
Summary:        SBLIM WBEM Command Line Interface
License:        EPL-1.0
Group:          System/Management

%description
WBEM Command Line Interface is a standalone, command line WBEM client.
It is especially suited for basic systems management tasks as it can be
used in scripts.



Authors:
--------
    SBLIM Project <http://www-124.ibm.com/sblim/>

%prep
%autosetup -p1

sed -i 's|wbemcli/samples|wbemcli/examples|' man/wbemcli.1.pre.in
sed -i 's|wbemcli/samples|wbemcli/examples|' man/wbemcli.1

%build
%configure
make %{?jobs:-j %jobs}

%install
%makeinstall
mv "samples" "examples"

%files
%defattr(-,root,root)
%doc ChangeLog README* NEWS examples/ *py
%{_bindir}/wbem*
%{_mandir}/man1/wbemcli.1.gz

%changelog
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
- Remove old SLE10 conditional
- Remove clean section
* Thu May 12 2016 mvetter@suse.com
- Requested by fate#319145
- Adding: sblim-wbemcli-allow-tls.patch:
  * Enable configurable SSL/TLS support
* Wed Oct 15 2014 kkaempf@suse.com
- Update to 1.6.3
  Bugfix release:
  Bugs:
  * 3519016 wbemcli does not support EmbeddedObject attr of PARAMVALUE
  * 3514126 wbemcli does not compile with GCC 4.7
  * 3495602 Fix for ID 3202420 (CDATA escape) breaks cim clients
  * 0002626 Add IPv6 LLA support to wbemcli
  * 0002627 Add -w option to wbemcli
  * 0002665 Add -e100 option to wbemcli
  * 0002629 Do not attempt connect if missing cacert
  * 0002721 wbemcli does not accept dot in userid:password
  * 0002626 bugfix for IPv6 LLA support
- Drop sblim-wbemcli-gcc47.patch, upstreamed
* Sat Mar 17 2012 dimstar@opensuse.org
- Add sblim-wbemcli-gcc47.patch: Fix build with gcc 4.7.
* Thu Jul 14 2011 kkaempf@novell.com
- update to 1.6.2
  Bugfix release:
  * 3324380 support optional CIMType in KEYVALUE element
  * 3216622 wbemcli throws parser error on CDATA string value
  * 2991546 Core dumps when property contains value within "[]"
* Tue Sep 14 2010 kkaempf@novell.com
- Fix SLE 10 build
* Wed Aug  5 2009 mhrusecky@suse.cz
- updated to 1.6.1
  - list of fixed bugs:
  * remove unnecessary ansidecl.h inclusion
  * fails to compile with gcc 3.3.3
  * remove deprecated const string to char conversion
  * segfaults on cm when objectpath is just classname
  * support for OpenSolaris
  * COPYING still contains CPL text
  * No Namespace in Response
  * should escape backslash character in CimXml::unescapeXml()
  * update man page with chunking option
  * gi quotes objetname in ref properties
  * apostrophe not unescaped correctly in xml
* Mon Jun  1 2009 mhrusecky@suse.cz
- fixed compilation issues in factory
* Tue Feb 10 2009 mhrusecky@suse.cz
- accepting patch to prevent segfault in some cases (bnc#474237)
- renaming directory with samples to examples
* Wed Sep  3 2008 mmarek@suse.cz
- updated to 1.6.0
  * re-licensed under the Eclipse Public License
  * bugfixes
* Tue Jul 29 2008 mmarek@suse.cz
- updated to 1.5.6
  * can specify IPv6 addresses on command line
  * bug fixes
* Thu Nov  1 2007 mmarek@suse.cz
- updated to 1.5.3
  Bugs (http://sourceforge.net/tracker/?group_id=128809):
  * 1560865 create/modifyInstance do not correctly deal with arrays
  * 1611024 support create/modifyInstance for Associations
  * 1632746 no error message on incorrect input values
  * 1652347 does not correctly handle VALUE.REFERENCE blocks
  * 1457924 fixed some compile warnings
- fixed some compiler warnings / errors
* Tue Jan 23 2007 aj@suse.de
- Add binutils-devel to BuildRequires to fix build.
* Wed Mar  1 2006 mrueckert@suse.de
- update to version 1.5.1 [#142308]
  * 1362712 wbemcli was failing on https connections with FC5
    Pegasus, forcing SSL V3 works around the failure.
  * 1362716 added default CA certificate file for https
    connections, added RH specific spec file.
- added sblim-wbemcli-1.5.1_parentheses.patch
  fixes "suggest parentheses around assignment used as truth value"
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Nov 14 2005 mrueckert@suse.de
- Update to version 1.5.0
  - removed all patches (applied upstream or obsoleted)
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Thu May  5 2005 schwab@suse.de
- Remove -gstabs+.
* Thu May  5 2005 schwab@suse.de
- Fix last change.
* Thu May  5 2005 ro@suse.de
- fix build with gcc-4
* Wed May 12 2004 nashif@suse.de
- Update to version 1.4.1
* Tue Mar 30 2004 ro@suse.de
- ppc64 is also a lib64 platform
* Mon Mar 22 2004 nashif@suse.de
- Initial release (1.4)
